@@ -15,8 +15,9 @@ BNULL = {"blank": True, "null": True}
 
 
 class SportEventType(models.TextChoices):
-    UNKNOWN = 'UK', _('Unknown')
+    UNKNOWN = 'UK', _('Event')
     GAME = 'GA', _('Game')
+    RACE = 'RA', _('Race')
     MATCH = 'MA', _('Match')
 
 
@@ -89,6 +90,7 @@ class Round(TheSportsDbMixin):
 class SportEvent(ScrobblableMixin):
     COMPLETION_PERCENT = getattr(settings, 'SPORT_COMPLETION_PERCENT', 90)
 
+    thesportsdb_id = models.CharField(max_length=255, **BNULL)
     event_type = models.CharField(
         max_length=2,
         choices=SportEventType.choices,
@@ -127,6 +129,18 @@ class SportEvent(ScrobblableMixin):
     def get_absolute_url(self):
         return reverse("sports:event_detail", kwargs={'slug': self.uuid})
 
+    @property
+    def subtitle(self):
+        return self.round.season.league
+
+    @property
+    def sportsdb_link(self):
+        return f"https://thesportsdb.com/event/{self.thesportsdb_id}"
+
+    @property
+    def info_link(self):
+        return self.sportsdb_link
+
     @classmethod
     def find_or_create(cls, data_dict: Dict) -> "Event":
         """Given a data dict from Jellyfin, does the heavy lifting of looking up
@@ -208,6 +222,7 @@ class SportEvent(ScrobblableMixin):
             away_team, _created = Team.objects.get_or_create(**away_team_dict)
 
         event_dict = {
+            "thesportsdb_id": data_dict.get("EventId"),
             "title": data_dict.get("Name"),
             "event_type": sport.default_event_type,
             "home_team": home_team,
